@@ -23,10 +23,10 @@ test_that("d.spls.lasso works", {
   expect_equal(dim(mod.dspls$fitted.values), c(n,ncp))
 
   #residuals
-  expect_setequal(mod.dspls$residuals, y-mod.dspls$fitted.values)
+  expect_equal(mod.dspls$residuals, y-mod.dspls$fitted.values, tolerance = 1e-5)
 
   #Mean of X
-  expect_setequal(apply(X, 2, mean), mod.dspls$Xmean)
+  expect_equal(apply(X, 2, mean), mod.dspls$Xmean, tolerance = 1e-5)
 
   #zerovar
   for (i in 2:ncp)
